import { connectableObject, initializableObject, SimpleConnectableObject } from "zrim-base-objects";
import { postGreSqlManager, PostGreSqlManager } from "./pgsql-manager";
import * as pgPromise from 'pg-promise';
export declare namespace simplePostGreSqlManager {
    interface Properties extends connectableObject.Properties {
        /**
         * The postgresql options
         */
        pgsqlOptions: PostGreSqlOptions;
        /**
         * The driver to use
         */
        pgsqlDriver?: pgPromise.IMain;
        /**
         * Flags
         */
        flags?: postGreSqlManager.Flags;
        /**
         * The database
         */
        database?: pgPromise.IDatabase<postGreSqlManager.DriverExtension>;
    }
    interface PostGreSqlOptions {
        /**
         * The connection string (url mode)
         */
        connectionUrl: string;
    }
    interface InitializeOptions extends initializableObject.InitializeOptions {
        /**
         *  The native options for the pg-promise driver
         */
        nativeDriverOptions?: object | undefined | null;
        /**
         * The connection string (url mode)
         */
        connectionUrl: string;
        /**
         * flags for the instance
         */
        flags?: postGreSqlManager.Flags | undefined | null;
    }
    interface CheckDataBaseConnectionOptions {
        /**
         * The client
         */
        client: pgPromise.IBaseProtocol<postGreSqlManager.DriverExtension>;
    }
    interface CheckDataBaseConnectionOnResolve {
        /**
         * flag for valid database
         */
        valid: boolean;
    }
    interface IsDataBaseInitializedOptions {
        /**
         * The client
         */
        client: pgPromise.IBaseProtocol<postGreSqlManager.DriverExtension>;
    }
    interface IsDataBaseInitializedOnResolve {
        /**
         * true if the database is initialized
         */
        initialized: boolean;
    }
    interface HandleDataBaseInitializationOptions {
        /**
         * The client
         */
        client: pgPromise.IBaseProtocol<postGreSqlManager.DriverExtension>;
    }
    interface HandleDataBaseInitializationOnResolve {
    }
    interface HandleCheckDataBaseHealthOptions {
        /**
         * Possible input the connection client to use to make the query. Null if we could not connect to the database
         */
        client?: pgPromise.IBaseProtocol<postGreSqlManager.DriverExtension> | undefined | null;
        /**
         * Possible input the error of the connection. Null if there were no problem
         */
        connectionError?: Error | undefined | null;
        /**
         * An array that checks if the operation is strong/weak
         */
        checkOperations: postGreSqlManager.CheckOperations[];
        /**
         * Possible input for additional options if the methods needs to be overwrite.
         */
        healthCheckOptions?: any | undefined | null;
        /**
         * The input context
         */
        inputContext?: any;
    }
    interface HandleCheckDataBaseHealthOnResolve {
        /**
         * flag for database healthy
         */
        healthy: boolean;
        /**
         * The check result
         */
        checkHealthResult?: any;
        /**
         * The possible error explication
         */
        error?: Error | undefined | null;
    }
}
/**
 * Simple implementation of the postgresql manager
 */
export declare class SimplePostGreSqlManager extends SimpleConnectableObject implements PostGreSqlManager {
    /**
     * @inheritDoc
     */
    protected properties: simplePostGreSqlManager.Properties;
    /**
     * @inheritDoc
     */
    readonly flags: postGreSqlManager.Flags | undefined;
    /**
     * @inheritDoc
     */
    readonly database: pgPromise.IDatabase<postGreSqlManager.DriverExtension> | undefined;
    /**
     * @inheritDoc
     */
    getFlags(): postGreSqlManager.Flags | undefined;
    /**
     * @inheritDoc
     */
    isReadOnly(): boolean;
    /**
     * @inheritDoc
     */
    initialize(options: simplePostGreSqlManager.InitializeOptions): Promise<void>;
    /**
     * @inheritDoc
     */
    checkDataBaseHealth(options: postGreSqlManager.CheckDataBaseHealthOptions): Promise<postGreSqlManager.CheckDataBaseHealthOnResolve>;
    /**
     * @inheritDoc
     */
    protected _handleInitialization(options: simplePostGreSqlManager.InitializeOptions, ...args: any[]): Promise<void>;
    /**
     * @inheritDoc
     */
    protected _handleDisconnection(...args: any[]): Promise<void>;
    /**
     * Check if the connection is valid
     * @param options
     */
    protected _checkDataBaseConnection(options: simplePostGreSqlManager.CheckDataBaseConnectionOptions): Promise<simplePostGreSqlManager.CheckDataBaseConnectionOnResolve>;
    /**
     * Check if teh database is initialized
     * @param options
     */
    protected _isDataBaseInitialize(options: simplePostGreSqlManager.IsDataBaseInitializedOptions): Promise<simplePostGreSqlManager.IsDataBaseInitializedOnResolve>;
    protected _handleDataBaseInitialization(options: simplePostGreSqlManager.HandleDataBaseInitializationOptions): Promise<simplePostGreSqlManager.HandleDataBaseInitializationOnResolve>;
    /**
     * @inheritDoc
     */
    protected _handleConnection(...args: any[]): Promise<void>;
    /**
     * Handle the database health check
     * @param options
     */
    protected _handleCheckDataBaseHealth(options: simplePostGreSqlManager.HandleCheckDataBaseHealthOptions): Promise<simplePostGreSqlManager.HandleCheckDataBaseHealthOnResolve>;
}
